@@ -29,18 +29,21 @@ class _ApplicationManagementKeywords(KeywordGroup):
             self, remote_url, platform_name,
             platform_version, device_name, app,
             automation_name=None, app_package=None, app_activity=None,
-            alias=None, bundleid=None, udid=None):
+            app_wait_package=None, app_wait_activity=None, alias=None, 
+            bundleid=None, udid=None):
         """Opens a new application to given Appium server.
 
         | *Option*          | *Man.* | *Description* |
         | remote_url        | Yes    | Appium server url |
         | platform_name     | Yes    | platform name, either "iOS" or "Android" |
         | platform_version  | Yes    | platform version, the mobile OS version you want |
-        | device_name       | Yes    | Device name, the kind of device you want, like "iPhone Simulator" |        
+        | device_name       | Yes    | Device name, the kind of device you want, like "iPhone Simulator" |
         | app               | Yes    | Android/iOS application path |
         | automation_name   | no     | "Selendroid" if you want to use Selendroid, otherwise, this can be omitted |
         | app_package       | no     | Android application package name |
         | app_activity      | no     | Android application activity name |
+        | app_wait_package  | no     | Java package of the Android app you want to wait for |        
+        | app_wait_activity | no     | Activity name for the Android activity you want to wait for |
         | alias             | no     | alias |
         | bundleid          | no     | iOS bundle ID  (e.g. com.yourCompany.yourApp). |
         | udid              | no     | UDID for iOS mobile device |
@@ -57,7 +60,9 @@ class _ApplicationManagementKeywords(KeywordGroup):
         desired_caps['app'] = app
         desired_caps['automationName'] = automation_name
         desired_caps['appPackage'] = app_package
+        desired_caps['appWaitPackage'] = app_wait_package
         desired_caps['androidActivity'] = app_activity
+        desired_caps['appWaitActivity'] = app_wait_activity
         desired_caps['bundleid'] = bundleid
         desired_caps['udid'] = udid
     
